==> google-cloud-gke-hub-1.5.2.tar.gz: google-cloud-gke-hub-1.5.2/google/cloud/gkehub/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from google.cloud.gkehub_v1.services.gke_hub.client import GkeHubClient
from google.cloud.gkehub_v1.services.gke_hub.async_client import GkeHubAsyncClient

from google.cloud.gkehub_v1.types.feature import CommonFeatureSpec
from google.cloud.gkehub_v1.types.feature import CommonFeatureState
from google.cloud.gkehub_v1.types.feature import Feature
from google.cloud.gkehub_v1.types.feature import FeatureResourceState
from google.cloud.gkehub_v1.types.feature import FeatureState
from google.cloud.gkehub_v1.types.feature import MembershipFeatureSpec
from google.cloud.gkehub_v1.types.feature import MembershipFeatureState
from google.cloud.gkehub_v1.types.membership import Authority
from google.cloud.gkehub_v1.types.membership import GkeCluster
from google.cloud.gkehub_v1.types.membership import KubernetesMetadata
from google.cloud.gkehub_v1.types.membership import KubernetesResource
from google.cloud.gkehub_v1.types.membership import Membership
from google.cloud.gkehub_v1.types.membership import MembershipEndpoint
from google.cloud.gkehub_v1.types.membership import MembershipState
from google.cloud.gkehub_v1.types.membership import ResourceManifest
from google.cloud.gkehub_v1.types.membership import ResourceOptions
from google.cloud.gkehub_v1.types.service import ConnectAgentResource
from google.cloud.gkehub_v1.types.service import CreateFeatureRequest
from google.cloud.gkehub_v1.types.service import CreateMembershipRequest
from google.cloud.gkehub_v1.types.service import DeleteFeatureRequest
from google.cloud.gkehub_v1.types.service import DeleteMembershipRequest
from google.cloud.gkehub_v1.types.service import GenerateConnectManifestRequest
from google.cloud.gkehub_v1.types.service import GenerateConnectManifestResponse
from google.cloud.gkehub_v1.types.service import GetFeatureRequest
from google.cloud.gkehub_v1.types.service import GetMembershipRequest
from google.cloud.gkehub_v1.types.service import ListFeaturesRequest
from google.cloud.gkehub_v1.types.service import ListFeaturesResponse
from google.cloud.gkehub_v1.types.service import ListMembershipsRequest
from google.cloud.gkehub_v1.types.service import ListMembershipsResponse
from google.cloud.gkehub_v1.types.service import OperationMetadata
from google.cloud.gkehub_v1.types.service import TypeMeta
from google.cloud.gkehub_v1.types.service import UpdateFeatureRequest
from google.cloud.gkehub_v1.types.service import UpdateMembershipRequest

__all__ = (
    "GkeHubClient",
    "GkeHubAsyncClient",
    "CommonFeatureSpec",
    "CommonFeatureState",
    "Feature",
    "FeatureResourceState",
    "FeatureState",
    "MembershipFeatureSpec",
    "MembershipFeatureState",
    "Authority",
    "GkeCluster",
    "KubernetesMetadata",
    "KubernetesResource",
    "Membership",
    "MembershipEndpoint",
    "MembershipState",
    "ResourceManifest",
    "ResourceOptions",
    "ConnectAgentResource",
    "CreateFeatureRequest",
    "CreateMembershipRequest",
    "DeleteFeatureRequest",
    "DeleteMembershipRequest",
    "GenerateConnectManifestRequest",
    "GenerateConnectManifestResponse",
    "GetFeatureRequest",
    "GetMembershipRequest",
    "ListFeaturesRequest",
    "ListFeaturesResponse",
    "ListMembershipsRequest",
    "ListMembershipsResponse",
    "OperationMetadata",
    "TypeMeta",
    "UpdateFeatureRequest",
    "UpdateMembershipRequest",
)

==> google-cloud-gke-hub-1.8.1.tar.gz: google-cloud-gke-hub-1.8.1/google/cloud/gkehub/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from google.cloud.gkehub import gapic_version as package_version

__version__ = package_version.__version__


from google.cloud.gkehub_v1.services.gke_hub.async_client import GkeHubAsyncClient
from google.cloud.gkehub_v1.services.gke_hub.client import GkeHubClient
from google.cloud.gkehub_v1.types.feature import (
    CommonFeatureSpec,
    CommonFeatureState,
    Feature,
    FeatureResourceState,
    FeatureState,
    MembershipFeatureSpec,
    MembershipFeatureState,
)
from google.cloud.gkehub_v1.types.membership import (
    Authority,
    GkeCluster,
    KubernetesMetadata,
    KubernetesResource,
    Membership,
    MembershipEndpoint,
    MembershipState,
    ResourceManifest,
    ResourceOptions,
)
from google.cloud.gkehub_v1.types.service import (
    ConnectAgentResource,
    CreateFeatureRequest,
    CreateMembershipRequest,
    DeleteFeatureRequest,
    DeleteMembershipRequest,
    GenerateConnectManifestRequest,
    GenerateConnectManifestResponse,
    GetFeatureRequest,
    GetMembershipRequest,
    ListFeaturesRequest,
    ListFeaturesResponse,
    ListMembershipsRequest,
    ListMembershipsResponse,
    OperationMetadata,
    TypeMeta,
    UpdateFeatureRequest,
    UpdateMembershipRequest,
)

__all__ = (
    "GkeHubClient",
    "GkeHubAsyncClient",
    "CommonFeatureSpec",
    "CommonFeatureState",
    "Feature",
    "FeatureResourceState",
    "FeatureState",
    "MembershipFeatureSpec",
    "MembershipFeatureState",
    "Authority",
    "GkeCluster",
    "KubernetesMetadata",
    "KubernetesResource",
    "Membership",
    "MembershipEndpoint",
    "MembershipState",
    "ResourceManifest",
    "ResourceOptions",
    "ConnectAgentResource",
    "CreateFeatureRequest",
    "CreateMembershipRequest",
    "DeleteFeatureRequest",
    "DeleteMembershipRequest",
    "GenerateConnectManifestRequest",
    "GenerateConnectManifestResponse",
    "GetFeatureRequest",
    "GetMembershipRequest",
    "ListFeaturesRequest",
    "ListFeaturesResponse",
    "ListMembershipsRequest",
    "ListMembershipsResponse",
    "OperationMetadata",
    "TypeMeta",
    "UpdateFeatureRequest",
    "UpdateMembershipRequest",
)
